@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 #include "mutt.h"
@@ -658,7 +658,7 @@ int mutt_save_message (HEADER *h, int delete,
 
     need_buffy_cleanup = (ctx.magic == M_MBOX || ctx.magic == M_MMDF || ctx.magic == M_KENDRA);
 
-    mx_close_mailbox (&ctx);
+    mx_close_mailbox (&ctx, NULL);
 
     if (need_buffy_cleanup)
     {
