@@ -15,8 +15,7 @@
  * 
  *     You should have received a copy of the GNU General Public
  *     License along with this program; if not, write to the Free
- *     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
- *     02139, USA.
+ *     Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 /* simple, editor-based message editing */
@@ -77,7 +76,7 @@ static int edit_one_message (CONTEXT *ctx, HEADER *cur)
 
   rc = mutt_append_message (&tmpctx, ctx, cur, 0, CH_NOLEN | CH_NOSTATUS); oerrno = errno;
 
-  mx_close_mailbox (&tmpctx);
+  mx_close_mailbox (&tmpctx, NULL);
 
   if (rc == -1)
   {
@@ -149,7 +148,7 @@ static int edit_one_message (CONTEXT *ctx, HEADER *cur)
   if (msg == NULL)
   {
     mutt_error (_("Can't append to folder: %s"), strerror (errno));
-    mx_close_mailbox (&tmpctx);
+    mx_close_mailbox (&tmpctx, NULL);
     goto bail;
   }
 
@@ -162,7 +161,7 @@ static int edit_one_message (CONTEXT *ctx, HEADER *cur)
   rc = mx_commit_message (msg, &tmpctx);
   mx_close_message (&msg);
   
-  mx_close_mailbox (&tmpctx);
+  mx_close_mailbox (&tmpctx, NULL);
   
   bail:
   if (fp) fclose (fp);
